@@ -114,17 +114,20 @@ def __get_google_location(city, state, zipcode, logger):
       components = response[0]['address_components']
       types = response[0]['types']
       location = response[0]['geometry']['location']
-      postcode_localities = response[0].get('postcode_localities')
+      postcode_localities = response[0].get('postcode_localities', None)
 
       data = { 'city': None, 'state': None, 'postcode': None }
       data['lat'] = location['lat']
       data['lng'] = location['lng']
 
       # when checking the response for a zipcode verify the city name is in the list of localities
-      if 'postal_code' in types:
-        matches = [l for l in postcode_localities if l.lower() == city.lower()]
+      if 'postal_code' in types and postcode_localities:
+        matches = [l for l in components if (
+                    'postal_localities' in l.types and
+                    (l.short_name.lower() == city.lower() or l.long_name.lower() == city.lower())
+        )]
 
-        if not  matches:
+        if not matches:
           return None
 
       for component in components:
