@@ -8,3 +8,5 @@ class Location:
     postcode: str
     county: str = field(default=None)
     country: str = field(default=None)
+    latitude: float = field(default=None)
+    longitude: float = field(default=None)
\ No newline at end of file
