@@ -2,6 +2,7 @@ from dataclasses import fields
 from cc_py_commons.transactions.transaction import Transaction
 
 def from_load(load):
+	"""Takes a freight-hub load and maps it to a pricing load (Transaction)"""
 	trans_data = {}
 
 	for field in fields(Transaction):
@@ -12,7 +13,8 @@ def from_load(load):
 			
 	trans_data['equipment'] = load.equipment_description
 	trans_data['all_in_cost'] = load.rate
-
+	trans_data['multi_stop'] = load.stops
+	
 	if isinstance(load.origin, dict):
 		trans_data['origin_city'] = load.origin['city']
 		trans_data['origin_state'] = load.origin['state']
